@@ -103,7 +103,7 @@ class Agent(CentraEntity):
         if fits_schema(os, OS):
             payload.params['os'] = os
         if labels:
-            payload.params['labels'] = [label.split(':')[1] for label in labels]
+            payload.params['labels'] = [label.split(':')[1] for label in labels if label]
         if label_groups:
             payload.params['label groups'] = label_groups
         if fits_schema(status, STATUS):
